@@ -11,7 +11,17 @@ summarise_.tbl_svy <- function(.data, ..., .dots) {
     unweighted = function(...) unweighted(..., .svy = .data)
   )
 
-  out <- lazyeval::lazy_eval(.dots, c(survey_funs, .data$variables))
+  if (inherits(.data$variables, "tbl_sql")) {
+    sql_vars <- lapply(tbl_vars(.data$variables), function(x) {
+      out <- dplyr::select_(.data$variables, x, attr(.data$variables, "order_var"))
+      out
+      })
+    names(sql_vars) <- tbl_vars(.data$variables)
+
+    out <- lazyeval::lazy_eval(.dots, c(survey_funs, sql_vars))
+  } else {
+    out <- lazyeval::lazy_eval(.dots, c(survey_funs, .data$variables))
+  }
   # use the argument names to name the output
   out <- lapply(seq_along(out), function(x) {
     stats::setNames(out[[x]], paste0(names(out[x]), names(out[[x]])))
@@ -36,7 +46,17 @@ summarise_.grouped_svy <- function(.data, ..., .dots) {
 
   groups <- as.character(groups(.data))
 
-  out <- lazyeval::lazy_eval(.dots, c(survey_funs, .data$variables))
+  if (inherits(.data$variables, "tbl_sql")) {
+    sql_vars <- lapply(tbl_vars(.data$variables), function(x) {
+      out <- dplyr::select_(.data$variables, x, attr(.data$variables, "order_var"))
+      out
+    })
+    names(sql_vars) <- tbl_vars(.data$variables)
+
+    out <- lazyeval::lazy_eval(.dots, c(survey_funs, sql_vars))
+  } else {
+    out <- lazyeval::lazy_eval(.dots, c(survey_funs, .data$variables))
+  }
   # use the argument names to name the output
   out <- lapply(seq_along(out), function(x) {
     unchanged_names <- groups
